@@ -476,7 +476,7 @@ class BaseOptimizer(ABC):
     def __init__(self, library, device='GPU', override_params=None):
         self.library = library
 
-        self.training_params, self.int_params = _get_params(library, device)
+        self.training_params, self.int_params = _get_params(self.library, device)
         self.training_params = _update_params(self.training_params, override_params)
 
     def optimize(self,
@@ -586,8 +586,7 @@ class BaseOptimizer(ABC):
 
 class OptimizerCB(BaseOptimizer):
     def __init__(self, device='GPU', override_params=None):
-        self.library = 'CB'
-        super(OptimizerCB, self).__init__(device, override_params)
+        super(OptimizerCB, self).__init__('CB', device, override_params)
 
     def get_obj(self, X_train, y_train, cat_features=None, n_folds=5, folds=None, max_rounds=5000, early_stopping=50, seed=0, verbose=1):
         # Catboost dataset
@@ -638,8 +637,7 @@ class OptimizerCB(BaseOptimizer):
 
 class OptimizerXGB(BaseOptimizer):
     def __init__(self, device='GPU', override_params=None):
-        self.library = 'XGB'
-        super(OptimizerXGB, self).__init__(device, override_params)
+        super(OptimizerXGB, self).__init__('XGB', device, override_params)
 
     def get_obj(self, X_train, y_train, cat_features=None, n_folds=5, folds=None, max_rounds=5000, early_stopping=50,
                 seed=0, verbose=1):
@@ -689,8 +687,7 @@ class OptimizerXGB(BaseOptimizer):
 
 class OptimizerLGB(BaseOptimizer):
     def __init__(self, device='CPU', override_params=None):
-        self.library = 'LGB'
-        super(OptimizerLGB, self).__init__(device, override_params)
+        super(OptimizerLGB, self).__init__('LGB', device, override_params)
 
     def get_obj(self, X_train, y_train, cat_features=None, n_folds=5, folds=None, max_rounds=5000, early_stopping=50,
                 seed=0, verbose=1):
